"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _clientFirehose = require("@aws-sdk/client-firehose");
var _nodeHttpHandler = require("@smithy/node-http-handler");
var _bluebird = _interopRequireDefault(require("bluebird"));
var _log = require("../utils/log");
/* eslint import/no-extraneous-dependencies: ["error", {"devDependencies": true}] */

class Connector {
  constructor({
    debug,
    deliveryStreamName = process.env.DELIVERY_STREAM_NAME,
    timeout = Number(process.env.FIREHOSE_TIMEOUT) || Number(process.env.TIMEOUT) || 1000
  }) {
    this.debug = msg => debug('%j', msg);
    this.deliveryStreamName = deliveryStreamName || 'undefined';
    this.stream = new _clientFirehose.FirehoseClient({
      requestHandler: new _nodeHttpHandler.NodeHttpHandler({
        requestTimeout: timeout,
        connectionTimeout: timeout
      }),
      logger: (0, _log.defaultDebugLogger)(debug)
    });
  }
  putRecordBatch(inputParams) {
    const params = {
      DeliveryStreamName: this.deliveryStreamName,
      ...inputParams
    };
    return _bluebird.default.resolve(this.stream.send(new _clientFirehose.PutRecordBatchCommand(params))).tap(this.debug).tapCatch(this.debug);
  }
}
var _default = exports.default = Connector;