"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _clientKinesis = require("@aws-sdk/client-kinesis");
var _nodeHttpHandler = require("@smithy/node-http-handler");
var _utilRetry = require("@smithy/util-retry");
var _bluebird = _interopRequireDefault(require("bluebird"));
var _retry = require("../utils/retry");
var _log = require("../utils/log");
/* eslint import/no-extraneous-dependencies: ["error", {"devDependencies": true}] */

class Connector {
  constructor({
    debug,
    streamName = process.env.STREAM_NAME,
    timeout = Number(process.env.KINESIS_TIMEOUT) || Number(process.env.TIMEOUT) || 1000,
    retryConfig = _retry.defaultRetryConfig
  }) {
    this.debug = msg => debug('%j', msg);
    this.streamName = streamName || 'undefined';
    this.stream = new _clientKinesis.KinesisClient({
      requestHandler: new _nodeHttpHandler.NodeHttpHandler({
        requestTimeout: timeout,
        connectionTimeout: timeout
      }),
      retryStrategy: new _utilRetry.ConfiguredRetryStrategy(11, _retry.defaultBackoffDelay),
      logger: (0, _log.defaultDebugLogger)(debug)
    });
    this.retryConfig = retryConfig;
  }
  putRecords(inputParams) {
    const params = {
      StreamName: this.streamName,
      ...inputParams
    };
    return this._putRecords(params, []);
  }
  _putRecords(params, attempts) {
    (0, _retry.assertMaxRetries)(attempts, this.retryConfig.maxRetries);
    return (0, _retry.wait)((0, _retry.getDelay)(this.retryConfig.retryWait, attempts.length)).then(() => _bluebird.default.resolve(this.stream.send(new _clientKinesis.PutRecordsCommand(params))).tap(this.debug).tapCatch(this.debug).then(resp => {
      if (resp.FailedRecordCount > 0) {
        return this._putRecords(unprocessed(params, resp), [...attempts, resp]);
      } else {
        return accumlate(attempts, resp);
      }
    }));
  }
}
var _default = exports.default = Connector;
const unprocessed = (params, resp) => ({
  ...params,
  Records: params.Records.filter((e, i) => resp.Records[i].ErrorCode)
});
const accumlate = (attempts, resp) => attempts.reduceRight((a, c) => ({
  ...a,
  Records: [...c.Records.filter(r => !r.ErrorCode), ...a.Records.filter(r => !r.ErrorCode)],
  attempts: [...attempts, resp]
}), resp);