"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _bluebird = _interopRequireDefault(require("bluebird"));
var _clientSns = require("@aws-sdk/client-sns");
var _nodeHttpHandler = require("@smithy/node-http-handler");
var _utilRetry = require("@smithy/util-retry");
var _retry = require("../utils/retry");
var _log = require("../utils/log");
/* eslint import/no-extraneous-dependencies: ["error", {"devDependencies": true}] */

class Connector {
  constructor({
    debug,
    topicArn = process.env.TOPIC_ARN,
    timeout = Number(process.env.SNS_TIMEOUT) || Number(process.env.TIMEOUT) || 1000,
    retryConfig = _retry.defaultRetryConfig
  }) {
    this.debug = msg => debug('%j', msg);
    this.topicArn = topicArn || 'undefined';
    this.topic = new _clientSns.SNSClient({
      requestHandler: new _nodeHttpHandler.NodeHttpHandler({
        requestTimeout: timeout,
        connectionTimeout: timeout
      }),
      retryStrategy: new _utilRetry.ConfiguredRetryStrategy(11, _retry.defaultBackoffDelay),
      logger: (0, _log.defaultDebugLogger)(debug)
    });
    this.retryConfig = retryConfig;
  }
  publish(inputParams) {
    const params = {
      TopicArn: this.topicArn,
      ...inputParams
    };
    return this._sendCommand(new _clientSns.PublishCommand(params));
  }
  publishBatch(inputParams) {
    const params = {
      TopicArn: this.topicArn,
      ...inputParams
    };
    return this._publishBatch(params, []);
  }
  _publishBatch(params, attempts) {
    (0, _retry.assertMaxRetries)(attempts, this.retryConfig.maxRetries);
    return (0, _retry.wait)((0, _retry.getDelay)(this.retryConfig.retryWait, attempts.length)).then(() => this._sendCommand(new _clientSns.PublishBatchCommand(params)).then(resp => {
      if (resp.Failed?.length > 0) {
        return this._publishBatch(unprocessed(params, resp), [...attempts, resp]);
      } else {
        return accumlate(attempts, resp);
      }
    }));
  }
  _sendCommand(command) {
    return _bluebird.default.resolve(this.topic.send(command)).tap(this.debug).tapCatch(this.debug);
  }
}
var _default = exports.default = Connector;
const unprocessed = (params, resp) => ({
  ...params,
  PublishBatchRequestEntries: resp.Failed.map(m => params.PublishBatchRequestEntries.find(e => m.Id === e.Id))
});
const accumlate = (attempts, resp) => attempts.reduceRight((a, c) => ({
  ...a,
  Successful: [...c.Successful, ...a.Successful],
  attempts: [...attempts, resp]
}), resp);