"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _bluebird = _interopRequireDefault(require("bluebird"));
var _clientSqs = require("@aws-sdk/client-sqs");
var _nodeHttpHandler = require("@smithy/node-http-handler");
var _utilRetry = require("@smithy/util-retry");
var _retry = require("../utils/retry");
var _log = require("../utils/log");
/* eslint import/no-extraneous-dependencies: ["error", {"devDependencies": true}] */

class Connector {
  constructor({
    debug,
    queueUrl = process.env.QUEUE_URL,
    timeout = Number(process.env.SQS_TIMEOUT) || Number(process.env.TIMEOUT) || 1000,
    retryConfig = _retry.defaultRetryConfig
  }) {
    this.debug = msg => debug('%j', msg);
    this.queueUrl = queueUrl || 'undefined';
    this.queue = new _clientSqs.SQSClient({
      requestHandler: new _nodeHttpHandler.NodeHttpHandler({
        requestTimeout: timeout,
        connectionTimeout: timeout
      }),
      retryStrategy: new _utilRetry.ConfiguredRetryStrategy(11, _retry.defaultBackoffDelay),
      logger: (0, _log.defaultDebugLogger)(debug)
    });
    this.retryConfig = retryConfig;
  }
  sendMessageBatch(inputParams) {
    const params = {
      QueueUrl: this.queueUrl,
      ...inputParams
    };
    return this._sendMessageBatch(params, []);
  }
  _sendMessageBatch(params, attempts) {
    (0, _retry.assertMaxRetries)(attempts, this.retryConfig.maxRetries);
    return (0, _retry.wait)((0, _retry.getDelay)(this.retryConfig.retryWait, attempts.length)).then(() => _bluebird.default.resolve(this.queue.send(new _clientSqs.SendMessageBatchCommand(params))).tap(this.debug).tapCatch(this.debug).then(resp => {
      if (resp.Failed?.length > 0) {
        return this._sendMessageBatch(unprocessed(params, resp), [...attempts, resp]);
      } else {
        return accumlate(attempts, resp);
      }
    }));
  }
}
var _default = exports.default = Connector;
const unprocessed = (params, resp) => ({
  ...params,
  Entries: resp.Failed.map(m => params.Entries.find(e => m.Id === e.Id))
});
const accumlate = (attempts, resp) => attempts.reduceRight((a, c) => ({
  ...a,
  Successful: [...c.Successful, ...a.Successful],
  attempts: [...attempts, resp]
}), resp);