"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.putObjectToS3 = exports.deleteObjectFromS3 = void 0;
var _highland = _interopRequireDefault(require("highland"));
var _s = _interopRequireDefault(require("../connectors/s3"));
var _faults = require("../utils/faults");
var _print = require("../utils/print");
var _ratelimit = require("../utils/ratelimit");
const putObjectToS3 = ({
  debug = (0, _print.debug)('s3'),
  bucketName = process.env.BUCKET_NAME,
  putRequestField = 'putRequest',
  putResponseField = 'putResponse',
  parallel = Number(process.env.S3_PARALLEL) || Number(process.env.PARALLEL) || 8,
  ...opt
} = {}) => {
  const connector = new _s.default({
    debug,
    bucketName
  });
  const putObject = uow => {
    if (!uow[putRequestField]) return (0, _highland.default)(Promise.resolve(uow));
    const p = connector.putObject(uow[putRequestField]).then(putResponse => ({
      ...uow,
      [putResponseField]: putResponse
    })).catch((0, _faults.rejectWithFault)(uow));
    return (0, _highland.default)(p); // wrap promise in a stream
  };
  return s => s.through((0, _ratelimit.ratelimit)(opt)).map(putObject).parallel(parallel);
};
exports.putObjectToS3 = putObjectToS3;
const deleteObjectFromS3 = ({
  debug,
  bucketName = process.env.BUCKET_NAME,
  deleteRequestField = 'deleteRequest',
  deleteResponseField = 'deleteResponse',
  parallel = Number(process.env.S3_PARALLEL) || Number(process.env.PARALLEL) || 8
} = {}) => {
  const connector = new _s.default({
    debug,
    bucketName
  });
  const deleteObject = uow => {
    if (!uow[deleteRequestField]) return (0, _highland.default)(Promise.resolve(uow));
    const p = connector.deleteObject(uow[deleteRequestField]).then(deleteResponse => ({
      ...uow,
      [deleteResponseField]: deleteResponse
    })).catch((0, _faults.rejectWithFault)(uow));
    return (0, _highland.default)(p); // wrap promise in a stream
  };
  return s => s.map(deleteObject).parallel(parallel);
};
exports.deleteObjectFromS3 = deleteObjectFromS3;